<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="94"/>
        <source>Take a screenshot</source>
        <translation>Ambil cuplikan layar</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="98"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[BERKAS1, BERKAS2, ...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../../upload/imageshackupload.cpp" line="49"/>
        <source>unknown error response</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../../upload/imgurupload.cpp" line="46"/>
        <source>unknown error response</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="145"/>
        <source>About</source>
        <translation>Tentang</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="146"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXQt Project: https://lxqt.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage - penampil gambar yang sederhana dan cepat

Hak cipta (C) 2013
Proyek LXQt: https://lxqt.org/

Pembuat:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="255"/>
        <source>Open File</source>
        <translation>Buka Berkas</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="256"/>
        <location filename="../../mainwindow.cpp" line="283"/>
        <source>Image files (%1)</source>
        <translation>Berkas gambar (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="262"/>
        <source>Open directory</source>
        <translation>Buka direktori</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="283"/>
        <source>Save File</source>
        <translation>Simpan Berkas</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="539"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Memuat...) - Penampil Gambar</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="544"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Gagal Dimuat) - Penampil Gambar</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="548"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Penampil Gambar</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="584"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Penampil Gambar</translation>
    </message>
    <message>
        <source>%1 (Loading...) - Image Viewer</source>
        <translation type="vanished">%1 (Memuat...) - Penampil Gambar</translation>
    </message>
    <message>
        <source>%1 (Failed to Load) - Image Viewer</source>
        <translation type="vanished">%1 (Gagal Dimuat) - Penampil Gambar</translation>
    </message>
    <message>
        <source>%1 (%2x%3) - Image Viewer</source>
        <translation type="vanished">%1 (%2x%3) - Penampil Gambar</translation>
    </message>
    <message>
        <source>Image Viewer</source>
        <translation type="vanished">Penampil Gambar</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="851"/>
        <source>Thumbnails</source>
        <translation>Gambar kecil</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="47"/>
        <source>Imgur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="48"/>
        <source>ImageShack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="124"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="127"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="130"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="137"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Penampil Gambar</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="162"/>
        <source>&amp;About</source>
        <translation>Tent&amp;ang</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="172"/>
        <source>&amp;Open File</source>
        <translation>&amp;Buka Berkas</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="175"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>&amp;Save</source>
        <translation>&amp;Simpan</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="188"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="198"/>
        <source>Save &amp;As</source>
        <translation>Simpan Seb&amp;agai</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="201"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="211"/>
        <source>&amp;Close</source>
        <translation>&amp;Tutup</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="214"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="224"/>
        <source>Zoom &amp;In</source>
        <translation>Per&amp;besar</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation type="vanished">Ctrl++</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="237"/>
        <source>Zoom &amp;Out</source>
        <translation>Per&amp;kecil</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="240"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="250"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Salin ke Papan Klip</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="260"/>
        <location filename="../../mainwindow.ui" line="263"/>
        <source>Next File</source>
        <translation>Berkas Berikutnya</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="vanished">Kanan</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="276"/>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>Previous File</source>
        <translation>Berkas Sebelumnya</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="vanished">Kiri</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="227"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="266"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="282"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="292"/>
        <source>Original Size</source>
        <translation>Ukuran Asli</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="295"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="305"/>
        <source>&amp;Fit</source>
        <translation>&amp;Pas</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="315"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Puta&amp;r Searah Jarum Jam</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="325"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Putar Ber&amp;lawanan Jarum Jam</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="330"/>
        <source>P&amp;references</source>
        <translation>P&amp;referensi</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="335"/>
        <source>&amp;Print</source>
        <translation>&amp;Cetak</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="338"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="348"/>
        <source>First File</source>
        <translation>Berkas Pertama</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="351"/>
        <source>Home</source>
        <translatorcomment>asumsi: nama tombol
</translatorcomment>
        <translation>Rumah</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="361"/>
        <source>Last File</source>
        <translation>Berkas Terakhir</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="364"/>
        <source>End</source>
        <translatorcomment>asumsi: nama tombol
</translatorcomment>
        <translation>Akhir</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="374"/>
        <source>&amp;New Window</source>
        <translation>Je&amp;ndela Baru</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="377"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="382"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Balikkan Arah &amp;Horisontal</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="392"/>
        <source>Capture Screenshot</source>
        <translation>Ambil Cuplikan Layar</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="400"/>
        <source>F&amp;ull Screen</source>
        <translation>Layar Pen&amp;uh</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="403"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="408"/>
        <source>Flip &amp;Vertically</source>
        <translation>Balikkan Arah &amp;Vertikal</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="418"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>Tem&amp;pel dari Papan Klip</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="431"/>
        <source>&amp;Slide Show</source>
        <translation>Pertunjukan &amp;Salindia</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="441"/>
        <source>&amp;Delete</source>
        <translation>&amp;Hapus</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="444"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="452"/>
        <source>Show Thumbnails</source>
        <translation>Tampilkan Gambar Kecil</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="457"/>
        <source>File Properties</source>
        <translation>Properti Berkas</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="465"/>
        <source>Open &amp;Directory</source>
        <translation>Buka &amp;Direktori</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="468"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="476"/>
        <source>Upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="479"/>
        <source>Upload the image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;Berkas</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>B&amp;antuan</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="78"/>
        <source>Go</source>
        <translation>Pergi</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="87"/>
        <source>&amp;View</source>
        <translation>&amp;Lihat</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;Sunting</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="123"/>
        <source>Toolbar</source>
        <translation>Bilah alat</translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation type="obsolete">Bilah Alat</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferensi</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Tema ikon:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Warna latar belakang normal:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Warna latar belakang layar penuh:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Interval salindia (detik):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Umum</translation>
    </message>
    <message>
        <source>TODO: Add configuration options here</source>
        <translation type="vanished">TODO: Tambahkan opsi konfigurasi di sini</translation>
    </message>
    <message>
        <source>Tab 1</source>
        <translation type="vanished">Tab 1</translation>
    </message>
    <message>
        <source>Tab 2</source>
        <translation type="vanished">Tab 2</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Cuplikan layar</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Ambil cuplikan layar</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Wilayah</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Seluruh layar</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Hanya jendela saat ini</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Tangkap area layar</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Sertakan kursor tetikus</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="74"/>
        <source> seconds</source>
        <translation> detik</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Tunda:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Sertakan rangka dan judul jendela</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
